# Generated by roxygen2: do not edit by hand

S3method(predict,krnn_fit)
S3method(print,fd_bayes_fit)
S3method(print,fd_gam_fit)
S3method(print,fd_logistic_fit)
S3method(print,fd_signed_depth)
S3method(print,krnn_cv)
S3method(print,krnn_fit)
export(bayes_depth_classify)
export(fm_depth)
export(gam_depth_classify)
export(krnn_cv)
export(krnn_fit)
export(krnn_smoother)
export(logistic_depth_classify)
export(plot_krnn_cv)
export(plot_krnn_smoother)
export(reference_curve)
export(signed_depth)
export(signed_distance_integral)
export(simulate_fd)
